==> ejc-ztpcdc-impl-3.0.0-20230811.071921-173-sources.jar: com/ejianc/business/dc/bean/DcDrawingApplyForEntity.java <==
package com.ejianc.business.dc.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import java.util.ArrayList;
import java.util.List;
/**
 * 图纸申请
 *
 * @author generator
 *
 */
@TableName("dc_drawing_apply_for")
public class DcDrawingApplyForEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="code")
    private String code; // 单据编号
    @TableField(value="name")
    private String name; // 单据名称
    @TableField(value="bill_state")
    private Integer billState; // 单据状态：0 自由态，1 已提交，2 审批中，3 审批通过，4 驳回，5 提交后有人审批中
    @TableField(value="project_id")
    private Long projectId; // 项目ID
    @TableField(value="project_code")
    private String projectCode; // 项目编码
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="engineering_type_id")
    private Long engineeringTypeId; // 工程类别ID
    @TableField(value="engineering_type")
    private String engineeringType; // 工程类别
    @TableField(value="apply_for_user_id")
    private Long applyForUserId; // 申请人员id
    @TableField(value="apply_for_user_name")
    private String applyForUserName; // 申请人姓名
    @TableField(value="apply_for_dept_id")
    private Long applyForDeptId; // 申请部门id
    @TableField(value="apply_for_dept_name")
    private String applyForDeptName; // 申请部门姓名
    @TableField(value="controlled_distribution")
    private String controlledDistribution; // 受控分发（1：是，0：否）
    @TableField(value="num")
    private Integer num; // 申请份数
    @TableField(value="org_id")
    private Long orgId; // 组织id
    @TableField(value="org_code")
    private String orgCode; // 组织编码
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="parent_org_id")
    private Long parentOrgId; // 所属组织id
    @TableField(value="parent_org_code")
    private String parentOrgCode; // 所属组织编码
    @TableField(value="parent_org_name")
    private String parentOrgName; // 所属组织名称
    @TableField(value="flow_state")
    private String flowState; // 流程状态--字典dc_tzk
    @TableField(value="flow_state_name")
    private String flowStateName; // 流程状态名称
    @TableField(value="dist_code")
    private String distCode; // 分发单号
    @TableField(value="dist_user_code")
    private String distUserCode; // 分发人编号
    @TableField(value="dist_user_name")
    private String distUserName; // 分发人姓名


    @TableField(exist=false)
    @SubEntity(serviceName="dcDrawingApplyForDrwgrpService")
    private List<DcDrawingApplyForDrwgrpEntity> dcDrawingApplyForDrwgrpList = new ArrayList<>(); // 图纸申请-卷册信息


    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getEngineeringTypeId() {
        return engineeringTypeId;
    }

    public void setEngineeringTypeId(Long engineeringTypeId) {
        this.engineeringTypeId = engineeringTypeId;
    }
    public String getEngineeringType() {
        return engineeringType;
    }

    public void setEngineeringType(String engineeringType) {
        this.engineeringType = engineeringType;
    }
    public Long getApplyForUserId() {
        return applyForUserId;
    }

    public void setApplyForUserId(Long applyForUserId) {
        this.applyForUserId = applyForUserId;
    }
    public String getApplyForUserName() {
        return applyForUserName;
    }

    public void setApplyForUserName(String applyForUserName) {
        this.applyForUserName = applyForUserName;
    }
    public Long getApplyForDeptId() {
        return applyForDeptId;
    }

    public void setApplyForDeptId(Long applyForDeptId) {
        this.applyForDeptId = applyForDeptId;
    }
    public String getApplyForDeptName() {
        return applyForDeptName;
    }

    public void setApplyForDeptName(String applyForDeptName) {
        this.applyForDeptName = applyForDeptName;
    }
    public String getControlledDistribution() {
        return controlledDistribution;
    }

    public void setControlledDistribution(String controlledDistribution) {
        this.controlledDistribution = controlledDistribution;
    }
    public Integer getNum() {
        return num;
    }

    public void setNum(Integer num) {
        this.num = num;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }


    public List<DcDrawingApplyForDrwgrpEntity> getDcDrawingApplyForDrwgrpList() {
        return dcDrawingApplyForDrwgrpList;
    }

    public void setDcDrawingApplyForDrwgrpList(List<DcDrawingApplyForDrwgrpEntity> dcDrawingApplyForDrwgrpList) {
        this.dcDrawingApplyForDrwgrpList = dcDrawingApplyForDrwgrpList;
    }

    public String getFlowState() {
        return flowState;
    }

    public void setFlowState(String flowState) {
        this.flowState = flowState;
    }

    public String getFlowStateName() {
        return flowStateName;
    }

    public void setFlowStateName(String flowStateName) {
        this.flowStateName = flowStateName;
    }

    public String getDistCode() {
        return distCode;
    }

    public void setDistCode(String distCode) {
        this.distCode = distCode;
    }

    public String getDistUserCode() {
        return distUserCode;
    }

    public void setDistUserCode(String distUserCode) {
        this.distUserCode = distUserCode;
    }

    public String getDistUserName() {
        return distUserName;
    }

    public void setDistUserName(String distUserName) {
        this.distUserName = distUserName;
    }
}

==> ejc-ztpcdc-impl-3.0.0-20250312.082320-383-sources.jar: com/ejianc/business/dc/bean/DcDrawingApplyForEntity.java <==
package com.ejianc.business.dc.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;
/**
 * 图纸申请
 *
 * @author generator
 *
 */
@TableName("dc_drawing_apply_for")
public class DcDrawingApplyForEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="code")
    private String code; // 单据编号
    @TableField(value="name")
    private String name; // 单据名称
    @TableField(value="bill_state")
    private Integer billState; // 单据状态：0 自由态，1 已提交，2 审批中，3 审批通过，4 驳回，5 提交后有人审批中
    @TableField(value="project_id")
    private Long projectId; // 项目ID
    @TableField(value="project_code")
    private String projectCode; // 项目编码
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="engineering_type_id")
    private Long engineeringTypeId; // 工程类别ID
    @TableField(value="engineering_type")
    private String engineeringType; // 工程类别
    @TableField(value="apply_for_user_id")
    private Long applyForUserId; // 申请人员id
    @TableField(value="apply_for_user_name")
    private String applyForUserName; // 申请人姓名
    @TableField(value="apply_for_dept_id")
    private Long applyForDeptId; // 申请部门id
    @TableField(value="apply_for_dept_name")
    private String applyForDeptName; // 申请部门姓名
    @TableField(value="controlled_distribution")
    private String controlledDistribution; // 受控分发（1：是，0：否）
    @TableField(value="num")
    private Integer num; // 申请份数
    @TableField(value="org_id")
    private Long orgId; // 组织id
    @TableField(value="org_code")
    private String orgCode; // 组织编码
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="parent_org_id")
    private Long parentOrgId; // 所属组织id
    @TableField(value="parent_org_code")
    private String parentOrgCode; // 所属组织编码
    @TableField(value="parent_org_name")
    private String parentOrgName; // 所属组织名称
    @TableField(value="flow_state")
    private String flowState; // 流程状态
    @TableField(value="flow_state_name")
    private String flowStateName; // 流程状态名称
    @TableField(value="dist_code")
    private String distCode; // 分发单号
    @TableField(value="dist_user_code")
    private String distUserCode; // 分发人编号
    @TableField(value="dist_user_name")
    private String distUserName; // 分发人姓名
    @TableField(value="dist_date")
    private Date distDate; // 分发日期


    @TableField(exist=false)
    @SubEntity(serviceName="dcDrawingApplyForDrwgrpService")
    private List<DcDrawingApplyForDrwgrpEntity> dcDrawingApplyForDrwgrpList = new ArrayList<>(); // 图纸申请-卷册信息


    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getEngineeringTypeId() {
        return engineeringTypeId;
    }

    public void setEngineeringTypeId(Long engineeringTypeId) {
        this.engineeringTypeId = engineeringTypeId;
    }
    public String getEngineeringType() {
        return engineeringType;
    }

    public void setEngineeringType(String engineeringType) {
        this.engineeringType = engineeringType;
    }
    public Long getApplyForUserId() {
        return applyForUserId;
    }

    public void setApplyForUserId(Long applyForUserId) {
        this.applyForUserId = applyForUserId;
    }
    public String getApplyForUserName() {
        return applyForUserName;
    }

    public void setApplyForUserName(String applyForUserName) {
        this.applyForUserName = applyForUserName;
    }
    public Long getApplyForDeptId() {
        return applyForDeptId;
    }

    public void setApplyForDeptId(Long applyForDeptId) {
        this.applyForDeptId = applyForDeptId;
    }
    public String getApplyForDeptName() {
        return applyForDeptName;
    }

    public void setApplyForDeptName(String applyForDeptName) {
        this.applyForDeptName = applyForDeptName;
    }
    public String getControlledDistribution() {
        return controlledDistribution;
    }

    public void setControlledDistribution(String controlledDistribution) {
        this.controlledDistribution = controlledDistribution;
    }
    public Integer getNum() {
        return num;
    }

    public void setNum(Integer num) {
        this.num = num;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }


    public List<DcDrawingApplyForDrwgrpEntity> getDcDrawingApplyForDrwgrpList() {
        return dcDrawingApplyForDrwgrpList;
    }

    public void setDcDrawingApplyForDrwgrpList(List<DcDrawingApplyForDrwgrpEntity> dcDrawingApplyForDrwgrpList) {
        this.dcDrawingApplyForDrwgrpList = dcDrawingApplyForDrwgrpList;
    }

    public String getFlowState() {
        return flowState;
    }

    public void setFlowState(String flowState) {
        this.flowState = flowState;
    }

    public String getFlowStateName() {
        return flowStateName;
    }

    public void setFlowStateName(String flowStateName) {
        this.flowStateName = flowStateName;
    }

    public String getDistCode() {
        return distCode;
    }

    public void setDistCode(String distCode) {
        this.distCode = distCode;
    }

    public String getDistUserCode() {
        return distUserCode;
    }

    public void setDistUserCode(String distUserCode) {
        this.distUserCode = distUserCode;
    }

    public String getDistUserName() {
        return distUserName;
    }

    public void setDistUserName(String distUserName) {
        this.distUserName = distUserName;
    }

    public Date getDistDate() {
        return distDate;
    }

    public void setDistDate(Date distDate) {
        this.distDate = distDate;
    }
}
